==> kdevelop_4.6.0.orig.tar.xz: kdevelop-4.6.0/debuggers/gdb/kdevgdb.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.
Comment[bs]=Ovaj dodatak pruža link za GDB, ispravljač grešaka izvornog nivoa za C, C++ i druge.
Comment[ca]=Aquest connector proveeix d'un frontal per GDB, un depurador a nivell de codi per C, C++ i més llenguatges.
Comment[ca@valencia]=Este connector proveeix d'un frontal per GDB, un depurador a nivell de codi per C, C++ i més llenguatges.
Comment[da]=Dette plugin sørger for en brugerflade til GDB, en fejlsøger til C, C++ og mere.
Comment[de]=Dieses Modul stellt eine Oberfläche für GDB zur Verfügung. GDB ist ein Debugger für C, C++ und weitere Sprachen.
Comment[el]=Αυτό το πρόσθετο προσφέρει ένα σύστημα περιβάλλοντος για το GDB, έναν διορθωτή επιπέδου πηγαίου κώδικα για τις C, C++ και άλλες γλώσσες.
Comment[en_GB]=This plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.
Comment[es]=Este complemento proporciona una interfaz para GDB, un depurador de código fuente para C, C++ y demás.
Comment[et]=See plugin pakub GDB kasutajaliidest. GDB on C, C++ ja veel mitme keele lähtekoodi tasandil tegutsev siluja.
Comment[fi]=Tämä liitännäinen tarjoaa GDB-käyttöliittymän, lähdekooditason virheenjäljittimen C-, C++-kielille ja paljon muuta
Comment[fr]=Ce module externe fournit une interface pour GDB, un débogueur au niveau des sources pour C, C++, etc.
Comment[ga]=Soláthraíonn an breiseán seo comhéadan ar GDB, dífhabhtóir foinse C, C++ agus a thuilleadh.
Comment[gl]=Este engadido fornece unha interface para GDB, un depurador a nivel do código fonte para C, C++ e outros.
Comment[hu]=Ez a bővítmény egy előtétprogramot szolgáltat a GDB-hez, egy forrásszintű hibakeresőt a C, C++ és további nyelvekhez.
Comment[it]=Questa estensione fornisce un'interfaccia per il GDB, un debugger a livello sorgente per C, C++ e altro.
Comment[ja]=このプラグインは、C, C++ などのソースレベルデバッガ GDB のフロントエンドを提供します。
Comment[kk]=Бұл плагин GDB, яғни C, C++ , т.б. бастапқы кодымен істейтін жөндегішке интерфейсі.
Comment[lv]=Šis spraudnis nodrošina priekšpusi GDB, C, C++ un cita pirmkoda atkļūdotāja.
Comment[nb]=Dette programtillegget gir en brukerflate til GDB, et feilsøkingsprogram på kildenivå for C og C++ og mer.
Comment[nds]=Dit Moduul stellt en Böversiet för GDB praat, en Bornkode-Fehlersöker för C, C++ un anner Spraken.
Comment[nl]=Deze plugin levert een frontend voor GDB, een broncodedebugger voor C, C++ en meer.
Comment[pl]=Ta wtyczka udostępnia interfejs do GDB, debuggera dla C, C++ i innych języków.
Comment[pt]=Este 'plugin' oferece uma interface para o GDB, um depurador a nível do código-fonte para C, C++, entre outros.
Comment[pt_BR]=Este plugin oferece uma interface para o GDB, um depurador em nível de código-fonte para C, C++, entre outros.
Comment[ru]=Это расширение предоставляет интерфейс к GDB, отладчику исходного кода для C, C++ и других языков.
Comment[sk]=Tento modul poskytuje rozhranie pre GDB, debuger pre C, C++ a ďalšie.
Comment[sl]=Ta vstavek prinaša začelje za GDB, razhroščevalnik na ravni izvorne kode za C, C++ in več.
Comment[sv]=Insticksprogrammet tillhandahåller ett gränssnitt till GDB, en källkodsavlusare för C, C++ med mera.
Comment[tr]=Bu eklenti, C, C++ ve daha fazlası için bir kaynak-düzeyinde hata ayıklayıcı olan GDB için bir önucu sağlar.
Comment[ug]=بۇ قىستۇرما GDB نىڭ ئالدى ئۇچىنى تەمىنلەيدۇ. GDB بولسا C، C++ ۋە باشقا تىللارنى ئەسلى كود ھالىتىدە سازلاش ئېلىپ بارالايدىغان سازلىغۇچتۇر.
Comment[uk]=Цей додаток надає можливість користуватися клієнтським інтерфейсом GDB, зневадника вихідного коду на C, C++ тощо.
Comment[x-test]=xxThis plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.xx
Comment[zh_CN]=此插件提供了 GDB 前端，GDB 是一个源码级的 C、C++ 等多语言的调试器。
Comment[zh_TW]=這個外掛程式提供 GDB 的前端介面。
Name=GDB Support
Name[bs]=GDB podrška
Name[ca]=Implementació de GDB
Name[ca@valencia]=Implementació de GDB
Name[cs]=Podpora GDB
Name[da]=GDB-understøttelse
Name[de]=Unterstützung für GDB
Name[el]=Υποστήριξη GDB
Name[en_GB]=GDB Support
Name[es]=Implementación de GDB
Name[et]=GDB toetus
Name[fi]=GDB-tuki
Name[fr]=Prise en charge de GDB
Name[ga]=Tacaíocht GDB
Name[gl]=Soporte de GDB
Name[hu]=GDB támogatás
Name[it]=Supporto GDB
Name[ja]=GDB サポート
Name[kk]=GDB қолдауы
Name[km]=គាំទ្រ GDB
Name[lv]=GDB atbalsts
Name[nb]=GDB-støtte
Name[nds]=GDB-Ünnerstütten
Name[nl]=Ondersteuning voor GDB
Name[pl]=Obsługa GDB
Name[pt]=Suporte a GDB
Name[pt_BR]=Suporte ao GDB
Name[ru]=Поддержка GDB
Name[sk]=Podpora GDB
Name[sl]=Podpora za GDB
Name[sv]=GDB stöd
Name[tr]=GDB Desteği
Name[ug]=GDB قوللىشى
Name[uk]=Підтримка GDB
Name[x-test]=xxGDB Supportxx
Name[zh_CN]=GDB 支持
Name[zh_TW]=GDB 支援
GenericName=Debugger Frontend
GenericName[bs]=Korisničko okruženje za ispravljač grešaka
GenericName[ca]=Frontal del depurador
GenericName[ca@valencia]=Frontal del depurador
GenericName[cs]=Rozhraní pro ladicí nástroj
GenericName[da]=Fejlsøgningsbrugerflade
GenericName[de]=Oberfläche für Debugger
GenericName[el]=Σύστημα περιβάλλοντος διορθωτή
GenericName[en_GB]=Debugger Frontend
GenericName[es]=Interfaz para el depurador
GenericName[et]=Siluja kasutajaliides
GenericName[eu]=Araztaile-interfazea
GenericName[fi]=Virheenjäljittimen käyttöliittymä
GenericName[fr]=Interface du débogueur
GenericName[ga]=Comhéadan Dífhabhtóra
GenericName[gl]=Interface para o depurador
GenericName[hi]=डिबगर फ्रन्टएण्ड
GenericName[hne]=डिबगर फ्रन्टएन्ड
GenericName[hu]=Grafikus felület nyomkövetéshez
GenericName[is]=Debugger Frontend
GenericName[it]=Interfaccia al debugger
GenericName[ja]=デバッガのフロントエンド
GenericName[kk]=Жөндегіш интерфейсі
GenericName[km]=ផ្នែក​ខាង​មុន​នៃ​កម្មវិធី​បំបាត់​កំហុស​​
GenericName[ko]=디버거 프론트엔드
GenericName[lv]=Atkļūdotāja priekšpuse
GenericName[nb]=Grensesnitt for feilsøker
GenericName[nds]=Fehlersöker-Böversiet
GenericName[nl]=Frontend voor debugger
GenericName[pl]=Interfejs do debuggera
GenericName[pt]=Interface do Depurador
GenericName[pt_BR]=Interface do depurador
GenericName[ro]=Interfață depanator
GenericName[ru]=Интегрированный отладчик
GenericName[sk]=Debuger rozhranie
GenericName[sl]=Začelje razhroščevalnika
GenericName[sv]=Gränssnitt till avlusare
GenericName[ta]=டிபக்கர் பிரான்டட்
GenericName[tg]=Интеграл ёфтани созгузор
GenericName[tr]=Hata Ayıklayıcı Önucu
GenericName[ug]=سازلىغۇچ ئالدى ئۇچى
GenericName[uk]=Клієнтська програма зневадника
GenericName[x-test]=xxDebugger Frontendxx
GenericName[zh_CN]=调试器前端
GenericName[zh_TW]=除錯器前端介面
Icon=debugger
X-KDE-Library=kdevgdb
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevgdb
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Debugging
ServiceTypes=KDevelop/Plugin
X-KDevelop-Interfaces=org.kdevelop.IStatus
X-KDevelop-IRequired=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=GUI

==> kdevelop-4.6.90.tar.xz: kdevelop-4.6.90/debuggers/gdb/kdevgdb.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=This plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.
Comment[bs]=Ovaj dodatak pruža link za GDB, ispravljač grešaka izvornog nivoa za C, C++ i druge.
Comment[ca]=Aquest connector proveeix d'un frontal per GDB, un depurador a nivell de codi per C, C++ i més llenguatges.
Comment[ca@valencia]=Este connector proveeix d'un frontal per GDB, un depurador a nivell de codi per C, C++ i més llenguatges.
Comment[da]=Dette plugin sørger for en brugerflade til GDB, en fejlsøger til C, C++ og mere.
Comment[de]=Dieses Modul stellt eine Oberfläche für GDB zur Verfügung. GDB ist ein Debugger für C, C++ und weitere.
Comment[el]=Αυτό το πρόσθετο προσφέρει ένα σύστημα περιβάλλοντος για το GDB, έναν διορθωτή επιπέδου πηγαίου κώδικα για τις C, C++ και άλλες γλώσσες.
Comment[en_GB]=This plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.
Comment[es]=Este complemento proporciona una interfaz para GDB, un depurador de código fuente para C, C++ y demás.
Comment[et]=See plugin pakub GDB kasutajaliidest. GDB on C, C++ ja veel mitme keele lähtekoodi tasandil tegutsev siluja.
Comment[fi]=Tämä liitännäinen tarjoaa GDB-käyttöliittymän, lähdekooditason virheenjäljittimen C-, C++-kielille ja paljon muuta
Comment[fr]=Ce module externe fournit une interface pour GDB, un débogueur au niveau des sources pour C, C++, etc.
Comment[ga]=Soláthraíonn an breiseán seo comhéadan ar GDB, dífhabhtóir foinse C, C++ agus a thuilleadh.
Comment[gl]=Este engadido fornece unha interface para GDB, un depurador a nivel do código fonte para C, C++ e outros.
Comment[hu]=Ez a bővítmény egy előtétprogramot szolgáltat a GDB-hez, egy forrásszintű hibakeresőt a C, C++ és további nyelvekhez.
Comment[it]=Questa estensione fornisce un'interfaccia per il GDB, un debugger a livello sorgente per C, C++ e altro.
Comment[ja]=このプラグインは、C, C++ などのソースレベルデバッガ GDB のフロントエンドを提供します。
Comment[kk]=Бұл плагин GDB, яғни C, C++ , т.б. бастапқы кодымен істейтін жөндегішке интерфейсі.
Comment[lv]=Šis spraudnis nodrošina priekšpusi GDB, C, C++ un cita pirmkoda atkļūdotāja.
Comment[nb]=Dette programtillegget gir en brukerflate til GDB, et feilsøkingsprogram på kildenivå for C og C++ og mer.
Comment[nds]=Dit Moduul stellt en Böversiet för GDB praat, en Bornkode-Fehlersöker för C, C++ un anner Spraken.
Comment[nl]=Deze plugin levert een frontend voor GDB, een broncodedebugger voor C, C++ en meer.
Comment[pl]=Ta wtyczka udostępnia interfejs do GDB, debuggera dla C, C++ i innych języków.
Comment[pt]=Este 'plugin' oferece uma interface para o GDB, um depurador a nível do código-fonte para C, C++, entre outros.
Comment[pt_BR]=Este plugin oferece uma interface para o GDB, um depurador em nível de código-fonte para C, C++, entre outros.
Comment[ru]=Это расширение предоставляет интерфейс к GDB, отладчику исходного кода для C, C++ и других языков.
Comment[sk]=Tento modul poskytuje rozhranie pre GDB, debuger pre C, C++ a ďalšie.
Comment[sl]=Ta vstavek prinaša začelje za GDB, razhroščevalnik na ravni izvorne kode za C, C++ in več.
Comment[sv]=Insticksprogrammet tillhandahåller ett gränssnitt till GDB, en källkodsavlusare för C, C++ med mera.
Comment[tr]=Bu eklenti, C, C++ ve daha fazlası için bir kaynak-düzeyinde hata ayıklayıcı olan GDB için bir önucu sağlar.
Comment[ug]=بۇ قىستۇرما GDB نىڭ ئالدى ئۇچىنى تەمىنلەيدۇ. GDB بولسا C، C++ ۋە باشقا تىللارنى ئەسلى كود ھالىتىدە سازلاش ئېلىپ بارالايدىغان سازلىغۇچتۇر.
Comment[uk]=Цей додаток надає можливість користуватися клієнтським інтерфейсом GDB, зневадника вихідного коду на C, C++ тощо.
Comment[x-test]=xxThis plugin provides a frontend for GDB, a source-level debugger for C, C++ and more.xx
Comment[zh_CN]=此插件提供了 GDB 前端，GDB 是一个源码级的 C、C++ 等多语言的调试器。
Comment[zh_TW]=這個外掛程式提供 GDB 的前端介面。
Name=GDB Support
Name[bs]=GDB podrška
Name[ca]=Implementació de GDB
Name[ca@valencia]=Implementació de GDB
Name[cs]=Podpora GDB
Name[da]=GDB-understøttelse
Name[de]=Unterstützung für GDB
Name[el]=Υποστήριξη GDB
Name[en_GB]=GDB Support
Name[es]=Implementación de GDB
Name[et]=GDB toetus
Name[fi]=GDB-tuki
Name[fr]=Prise en charge de GDB
Name[ga]=Tacaíocht GDB
Name[gl]=Soporte de GDB
Name[hu]=GDB támogatás
Name[it]=Supporto GDB
Name[ja]=GDB サポート
Name[kk]=GDB қолдауы
Name[km]=គាំទ្រ GDB
Name[lv]=GDB atbalsts
Name[nb]=GDB-støtte
Name[nds]=GDB-Ünnerstütten
Name[nl]=Ondersteuning voor GDB
Name[pl]=Obsługa GDB
Name[pt]=Suporte a GDB
Name[pt_BR]=Suporte ao GDB
Name[ru]=Поддержка GDB
Name[sk]=Podpora GDB
Name[sl]=Podpora za GDB
Name[sv]=GDB stöd
Name[tr]=GDB Desteği
Name[ug]=GDB قوللىشى
Name[uk]=Підтримка GDB
Name[x-test]=xxGDB Supportxx
Name[zh_CN]=GDB 支持
Name[zh_TW]=GDB 支援
GenericName=Debugger Frontend
GenericName[bs]=Korisničko okruženje za ispravljač grešaka
GenericName[ca]=Frontal del depurador
GenericName[ca@valencia]=Frontal del depurador
GenericName[cs]=Rozhraní pro ladicí nástroj
GenericName[da]=Fejlsøgningsbrugerflade
GenericName[de]=Oberfläche für Debugger
GenericName[el]=Σύστημα περιβάλλοντος διορθωτή
GenericName[en_GB]=Debugger Frontend
GenericName[es]=Interfaz para el depurador
GenericName[et]=Siluja kasutajaliides
GenericName[eu]=Araztaile-interfazea
GenericName[fi]=Virheenjäljittimen käyttöliittymä
GenericName[fr]=Interface du débogueur
GenericName[ga]=Comhéadan Dífhabhtóra
GenericName[gl]=Interface para o depurador
GenericName[hi]=डिबगर फ्रन्टएण्ड
GenericName[hne]=डिबगर फ्रन्टएन्ड
GenericName[hu]=Grafikus felület nyomkövetéshez
GenericName[is]=Debugger Frontend
GenericName[it]=Interfaccia al debugger
GenericName[ja]=デバッガのフロントエンド
GenericName[kk]=Жөндегіш интерфейсі
GenericName[km]=ផ្នែក​ខាង​មុន​នៃ​កម្មវិធី​បំបាត់​កំហុស​​
GenericName[ko]=디버거 프론트엔드
GenericName[lv]=Atkļūdotāja priekšpuse
GenericName[nb]=Grensesnitt for feilsøker
GenericName[nds]=Fehlersöker-Böversiet
GenericName[nl]=Frontend voor debugger
GenericName[pl]=Interfejs do debuggera
GenericName[pt]=Interface do Depurador
GenericName[pt_BR]=Interface do depurador
GenericName[ro]=Interfață depanator
GenericName[ru]=Интегрированный отладчик
GenericName[sk]=Debuger rozhranie
GenericName[sl]=Začelje razhroščevalnika
GenericName[sv]=Gränssnitt till avlusare
GenericName[ta]=டிபக்கர் பிரான்டட்
GenericName[tg]=Интеграл ёфтани созгузор
GenericName[tr]=Hata Ayıklayıcı Önucu
GenericName[ug]=سازلىغۇچ ئالدى ئۇچى
GenericName[uk]=Клієнтська програма зневадника
GenericName[x-test]=xxDebugger Frontendxx
GenericName[zh_CN]=调试器前端
GenericName[zh_TW]=除錯器前端介面
Icon=debugger
X-KDE-Library=kdevgdb
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDE-PluginInfo-Name=kdevgdb
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Debugging
ServiceTypes=KDevelop/Plugin
X-KDevelop-Interfaces=org.kdevelop.IStatus
X-KDevelop-IRequired=org.kdevelop.IExecutePlugin
X-KDevelop-Mode=GUI
